@@ -8,6 +8,32 @@
 //!     let (x, y) = (x, y).map(|a| a + 5);
 //!     assert_eq!(x, 8);
 //!     assert_eq!(y, 9);
+//!
+//!     let v = (3, 4, 5, 6).fold(vec![], |mut v, x| {
+//!         if x % 3 == 0 {
+//!             v.push(x);
+//!         }
+//!         v
+//!     });
+//!     assert_eq!(v, vec![3, 6]);
+//!
+//!     assert!((3, 3, 3).same());
+//!
+//!     assert_eq!((3, 4, 5).nth(1), Some(4));
+//!
+//!     assert_eq!((3, 4, 5).add((1, 2, 3)), (4, 6, 8));
+//!
+//!     let a = (1, 2, 3);
+//!     let b = ("a", "b", "c");
+//!     assert_eq!(
+//!         a.zipf(b, |x, y| format!("{}{}", x, y)),
+//!         ("1a", "2b", "3c").map(|x| x.to_owned())
+//!     );
+//!
+//!     assert_eq!(a.sum(), 6);
+//!
+//!     assert_eq!(a.tmax(), 3);
+//!     assert_eq!(a.tmin(), 1);
 //! }
 //! ```
 //!
@@ -184,6 +210,20 @@ macro_rules! impl_tuple_map {
             where
                  Self::Item: ::std::ops::MulAssign;
 
+            /// Takes `(a, b, c, ...)` then returns the maximum value of tuple.
+            /// This method is named `tmax` instead of `max`, to avoid overlap
+            /// to `std::cmp::ord::max`.
+            fn tmax(self) -> Self::Item
+            where
+                Self::Item: ::std::cmp::PartialOrd;
+
+            /// Takes `(a, b, c, ...)` then returns the minimum value of tuple.
+            /// This method is named `tmin` instead of `min`, to avoid overlap
+            /// to `std::cmp::ord::min`.
+            fn tmin(self) -> Self::Item
+            where
+                Self::Item: ::std::cmp::PartialOrd;
+            
             /// Takes `(a, a, a, ...)` and `(b, b, b, ...)` then returns `((a, b), (a, b), (a, b), ...)` 
             /// # Example
             /// ```ignore
@@ -404,6 +444,30 @@ macro_rules! impl_tuple_map {
                 acc
             }
 
+            #[allow(unused_mut)]
+            fn tmax(self) -> Self::Item
+            where
+                Self::Item: ::std::cmp::PartialOrd
+            {
+                let (mut acc, $($name_reduced,)*) = self;
+                $(if acc < $name_reduced {
+                    acc = $name_reduced;
+                })*
+                acc
+            }
+
+            #[allow(unused_mut)]
+            fn tmin(self) -> Self::Item
+            where
+                Self::Item: ::std::cmp::PartialOrd
+            {
+                let (mut acc, $($name_reduced,)*) = self;
+                $(if acc > $name_reduced {
+                    acc = $name_reduced;
+                })*
+                acc
+            }
+
             fn zip<U, B>(self, other: U) -> ($((Self::$item, $other),)*)
             where
                 U: $trait<Item = B>
@@ -716,4 +780,16 @@ mod tests {
         let a = (6, 8, 10);
         assert_eq!(a.product(), 480);
     }
+
+    #[test]
+    fn test_tmin() {
+        let a = (6, 8, 10);
+        assert_eq!(a.tmin(), 6);
+    }
+
+    #[test]
+    fn test_tmax() {
+        let a = (6, 8, 10);
+        assert_eq!(a.tmax(), 10);
+    }
 }
